#!/usr/bin/env python
"""Tests for `deluge_cmd` package."""

import pytest
from click.testing import CliRunner

from deluge_cmd import cli


@pytest.fixture
def response():
    """Sample pytest fixture.

    See more at: http://doc.pytest.org/en/latest/fixture.html
    """
    # import requests
    # return requests.get('https://github.com/audreyr/cookiecutter-pypackage')


def test_content(response):
    """Sample pytest test function with the pytest fixture as an argument."""
    # from bs4 import BeautifulSoup
    # assert 'GitHub' in BeautifulSoup(response.content).title.string
    del response


def test_command_line_interface():
    """Test the CLI."""
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 0
    assert 'deluge_cmd' in result.output
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--help  Show this message and exit.' in help_result.output



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['deluge_cmd', 'tests']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0', 'deluge-card>=0.2.3,<0.3.0']

entry_points = \
{'console_scripts': ['deluge_cmd = deluge_cmd.cli:main',
                     'dsd = deluge_cmd.deluge_cmd.sdu:main']}

setup_kwargs = {
    'name': 'deluge-cmd',
    'version': '0.1.3',
    'description': 'Command line tools to manage Synthstrom deluge SD card contents.',
    'long_description': '# deluge-cmd\n\n\n[![pypi](https://img.shields.io/pypi/v/deluge-cmd.svg)](https://pypi.org/project/deluge-cmd/)\n[![python](https://img.shields.io/pypi/pyversions/deluge-cmd.svg)](https://pypi.org/project/deluge-cmd/)\n[![Build Status](https://github.com/mupaduw/deluge-cmd/actions/workflows/dev.yml/badge.svg)](https://github.com/mupaduw/deluge-cmd/actions/workflows/dev.yml)\n[![codecov](https://codecov.io/gh/mupaduw/deluge-cmd/branch/main/graphs/badge.svg)](https://codecov.io/github/mupaduw/deluge-cmd)\n\n\nSome cli tools to manage Synthstrom Deluge SD card contents.\n\n* Documentation: <https://mupaduw.github.io/deluge-cmd>\n* GitHub: <https://github.com/mupaduw/deluge-cmd>\n* PyPI: <https://pypi.org/project/deluge-cmd/>\n* Free software: MIT\n\n\n## Features\n\n- verify Deluge Filesytem structure\n- list songs \n- list song attributes bpm, key, samples\n- list samples (used/unused)\n\n### Planned features\n- move songs, samples \n- delete songs, samples\n- posix-like glob filtering for list, move & delete\n- list instruments and types\n- anything helpful for backward/forward migration of deluge SD cards having fw3.15 and 4.0 content.\n\n## Credits\n\nThis package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.\n',
    'author': 'Chris B Chamberlain',
    'author_email': 'chrisbc@artisan.co.nz',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/mupaduw/deluge-cmd',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



"""Main dsd script."""

import argparse

from deluge_card import list_deluge_fs

from .dsd_helpers import list_samples, list_song_samples, list_songs


def main():
    """Main entrypoint."""
    parser = argparse.ArgumentParser(description='list deluge_card contents')
    parser.add_argument('folder', type=str, nargs='+', help='one or more folder to check')
    parser.add_argument(
        '-l', '--list', help='one of of s=songs, a=samples, S=song_samples (future: K=Kit, I=instrument)'
    )
    parser.add_argument("-v", "--verbose", help="increase output verbosity", action="store_true")
    parser.add_argument("-s", "--summary", help="summarise output", action="store_true")

    args = parser.parse_args()

    for fname in args.folder:
        card_imgs = list_deluge_fs(fname)
        if len(card_imgs):
            for c in card_imgs:
                print(f'Deluge filesystem at {c.card_root()} mounted: {c.is_mounted()}')
                if args.list == 's':
                    list_songs(c, args)
                if args.list == 'a':
                    list_samples(c, args)
                if args.list == 'S':
                    list_song_samples(c, args)


if __name__ == '__main__':
    main()  # pragma: no cover
